fuelbuddy.getAverage = function(chartdata, key) {
	var avg = 0;
	var count = 0;
	$.each(chartdata, function(i, item) {
		avg += parseFloat(item[key]);
		//avg = avg / (i+1);
		count = i + 1;
	});
	return avg / count;
}

fuelbuddy.showChart = function(chartName, chartTitle, processData, drawChart) {
	$("#chart-area").removeClass("hidden");
	$("#chart-title").html(chartTitle);
	$("#chart-body").html("<i class='fa fa-spinner fa-spin'></i>  Loading ...");
	
	jQuery.get(fuelbuddy.CHARTS_PHP + '?vehid=' + fuelbuddy.current_vehicle_id 
		+ "&startDate="  + fuelbuddy.current_start_date 
		+ "&endDate=" + fuelbuddy.current_end_date
		+ "&chart-name=" + chartName , "", function(chartdata) { 
		
			if (chartdata.length == 0) {
				$("#chart-body").html("No matching data found");
				return;
			}
			
			var processedChartData = processData(chartdata);

			$("#chart-body").empty();
	
			drawChart(processedChartData);
	}, "json")
}

// Common function for showing service/expense per mi/day charts
fuelbuddy.showSEcharts = function(chartid, title) {
	
	var morrisFunction;
	if (chartid.indexOf("per-day") > 0) {
		morrisFunction = function(chartdata) {
			Morris.Area({
				element: 'chart-body',
				lineColors: ['#e0a900'],
				data: chartdata,
				xkey: 'date',
				ykeys: ['cost'],
				labels: ['cost'],
				parseTime: false,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		};
	} else {
		morrisFunction = function(chartdata) {
			Morris.Area({
				element: 'chart-body',
				lineColors: ['#e0a900'],
				data: chartdata,
				xkey: 'date',
				ykeys: ['cost'],
				labels: ['cost'],
				goals: [fuelbuddy.dashboard_stats[chartid]],
				goalStrokeWidth: 1,
				goalLineColors: ["#e0a900"],
				parseTime: false,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		};
	}
	
	
	fuelbuddy.showChart(chartid,
		title,
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": dayMonthAndYear,
					"cost": parseFloat(item["cost"]).toFixed(2)
				});
			});
			return tmpChartData;
		},
		morrisFunction
	);	
}


fuelbuddy.showServiceCostPerDistanceChart = function() {
	fuelbuddy.showSEcharts(
		"service-cost-per-distance",
		"Service Cost/" + fuelbuddy.global_settings["distance"]);
}

fuelbuddy.showServiceCostPerDayChart = function() {
	fuelbuddy.showSEcharts(
		"service-cost-per-day",
		"Service Cost/day");
}

fuelbuddy.showExpenseCostPerDistanceChart = function() {
	fuelbuddy.showSEcharts(
		"expense-cost-per-distance",
		"Expense Cost/" + fuelbuddy.global_settings["distance"]);
	}

fuelbuddy.showExpenseCostPerDayChart = function() {
	fuelbuddy.showSEcharts(
		"expense-cost-per-day",
		"Expense Cost/day");
}

fuelbuddy.showAvgFuelEfficiencyChart = function() {
	fuelbuddy.showChart("avg-fuel-efficiency",
		"Avg Fuel Efficiency",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				
				var consumption = (fuelbuddy.global_settings["consumption"] === "L/100km") 
					? 100 / parseFloat(item["consumption"])
					: parseFloat(item["consumption"]);
				
				tmpChartData.push({
					"date": dayMonthAndYear,
					"consumption": consumption
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Area({
				element: 'chart-body',
				lineColors: ['#e0a900'],
				data: chartdata,
				xkey: 'date',
				goals: [fuelbuddy.getAverage(chartdata, "consumption")],
				goalStrokeWidth: 1,
				goalLineColors: ["#e0a900"],
				ykeys: ['consumption'],
				labels: ['consumption'],
				parseTime: false,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}
	
	
fuelbuddy.showPricePerVolumeChart = function() {
	fuelbuddy.showChart("avg-price-per-volume",
		"Avg Price",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": dayMonthAndYear,
					"cost": parseFloat(item["cost"]).toFixed(3)
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Area({
				element: 'chart-body',
				lineColors: ['#e0a900'],
				data: chartdata,
				goals: [fuelbuddy.getAverage(chartdata, "cost")],
				goalStrokeWidth: 1,
				goalLineColors: ["#e0a900"],
				xkey: 'date',
				ykeys: ['cost'],
				labels: ['cost'],
				parseTime: false,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
				yLabelFormat: function(y) { return y.toFixed(3);}
			});
		}
	);
}

fuelbuddy.showDistanceBetweenFillupsChart = function() {
	fuelbuddy.showChart("distance-between-fillups",
		"Distance Between Fill-Ups",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": dayMonthAndYear,
					"dist": parseFloat(item["dist"]).toFixed(2)
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			var minDist = 10000;
			var avgDistance = 0;
			$.each(chartdata, function(i, item) {
				avgDistance += parseFloat(item["dist"]);
				avgDistance = avgDistance / (i+1);
				if (parseFloat(item["dist"]) < minDist) {
					minDist = parseFloat(item["dist"]);
				}
			});
			Morris.Area({
			  element: 'chart-body',
				lineColors: ['#e0a900'],
			  data: chartdata,
			  xkey: 'date',
			  ykeys: ['dist'],
			  labels: ['dist'],
			  goals: [fuelbuddy.getAverage(chartdata, "dist")],
			  goalStrokeWidth: 1,
			  goalLineColors: ["#e0a900"],
			  parseTime: false,
			  ymin: minDist - 50,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
			  yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}

fuelbuddy.showFillUpsPerMonthChart = function() {
	fuelbuddy.showChart("fill-ups-per-month",
		"Fill-Ups Per Month",
		function(chartdata) {
			var tmpChartData = [];		
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var monthAndYear = ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": monthAndYear,
					"fillups": parseInt(item["fillups"])
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Bar({
			  element: 'chart-body',
				barColors: ['#e0a900'],
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
			  data: chartdata,
			  xkey: 'date',
			  ykeys: ['fillups'],
			  labels: ['Fillups'],
			});
		}
	);
}

fuelbuddy.showFuelCostByDistanceChart = function() {
	fuelbuddy.showChart("fuel-cost-per-distance",
		"Fuel Cost/" + fuelbuddy.global_settings["distance"],
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.unshift({
					"date": dayMonthAndYear,
					"cost": parseFloat(item["cost"]).toFixed(2),
					"dist": parseFloat(item["dist"]).toFixed(2),
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			var totalCost = 0;
			var totalDist = 0;
			$.each(chartdata, function(i, item) {
				totalCost = totalCost + (parseFloat(item["cost"]) * parseFloat(item["dist"]));
				totalDist = totalDist + parseFloat(item["dist"]);
			});
			
			var avgCost = (totalCost / totalDist).toFixed(2);
			console.log("Avg cost per mile = " + avgCost);
			Morris.Area({
				element: 'chart-body',
				lineColors: ['#e0a900'],
				data: chartdata,
				xkey: 'date',
				ykeys: ['cost'],
				goals: [avgCost],
				goalStrokeWidth: 1,
				goalLineColors: ["#e0a900"],
				labels: ['cost'],
				parseTime: false,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}


fuelbuddy.showFuelCostByDayChart = function() {
	fuelbuddy.showChart("fuel-cost-per-day",
		"Fuel Cost/day",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var dayMonthAndYear = ("0"+(d.getDate())).slice(-2) + "/" + ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": dayMonthAndYear,
					"cost": parseFloat(item["cost"]).toFixed(2)
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Area({
				element: 'chart-body',
				lineColors: ['#e0a900'],
				data: chartdata,
				xkey: 'date',
				// goals: [fuelbuddy.getAverage(chartdata, "cost")],
				// goalStrokeWidth: 1,
				// goalLineColors: ["#e0a900"],
				ykeys: ['cost'],
				labels: ['cost'],
				parseTime: false,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}


fuelbuddy.showFuelCostByMonthChart = function() {
	fuelbuddy.showChart("fuel-cost-per-month",
		"Fuel Cost/month",
		function(chartdata) {
			var tmpChartData = [];
			$.each(chartdata, function(i, item) {
				var d = new Date(parseInt(item["date"]));
				var monthAndYear = ("0"+(d.getMonth()+1)).slice(-2) + "/" + d.getFullYear();
				tmpChartData.push({
					"date": monthAndYear,
					"cost": parseFloat(item["cost"]).toFixed(2)
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Bar({
				element: 'chart-body',
				barColors: ['#e0a900'],
				data: chartdata,
				xkey: 'date',
				goals: [fuelbuddy.getAverage(chartdata, "cost")],
				goalStrokeWidth: 1,
				goalLineColors: ["#e0a900"],
				ykeys: ['cost'],
				labels: ['cost'],
				parseTime: false,
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
				yLabelFormat: function(y) { return y.toFixed(2);}
			});
		}
	);
}

fuelbuddy.showTaxDeductionByTypeChart = function() {
	fuelbuddy.showChart("trip-tax-deduction-by-type",
		"Trip Tax Deduction by Type",
		function(chartdata) {
			var tmpChartData = [];		
			$.each(chartdata, function(i, item) {
				tmpChartData.push({
					"cost": item["cost"],
					"type": item["type"]
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Bar({
			  element: 'chart-body',
			  barColors: ['#e0a900'],
			  data: chartdata,
			  xkey: 'type',
			  ykeys: ['cost'],
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
			  labels: ['cost'],
			});
		}
	);
}

fuelbuddy.showTripDistanceByTypeChart = function() {
	fuelbuddy.showChart("trip-dist-by-type",
		"Trip Distance by Type",
		function(chartdata) {
			var tmpChartData = [];		
			$.each(chartdata, function(i, item) {
				tmpChartData.push({
					"dist": item["dist"],
					"type": item["type"]
				});
			});
			return tmpChartData;
		},
		function(chartdata) {
			Morris.Bar({
			  element: 'chart-body',
				barColors: ['#e0a900'],
			  data: chartdata,
			  xkey: 'type',
			  ykeys: ['dist'],
				fillOpacity: .85,
				pointSize: 2,
				lineWidth: 2,
				hideHover: 'auto',
			  labels: ['dist'],
			});
		}
	);
}

